docs.rs failed to build nahpu_db-0.1.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
NAHPU DB
A utility crate for the NAHPU project that handles the database schema and models.
Features
- Fetches the latest SQLite schema (Drift file) from the main NAHPU repository during the build process.
- Auto-generates Rust
structdefinitions corresponding to the SQLite tables usingsqlparser. - Provides
serde-compatible models with camelCase JSON representation for seamless integration with other tools (e.g. Darwin Core conversion).
Usage
This crate is primarily used internally by other NAHPU utility crates, such as nahpu_dwc, to ensure type safety and schema alignment.